@@ -206,8 +206,7 @@ pub fn pn2codon(
     let mut dont_skip = RefCell::new(true);   
     let seq_length = seqs.len();
     let mut ret = vec![Vec::<String>::new(); seq_length];
-   
-    
+       
 
     seqs
         .iter()
@@ -226,12 +225,10 @@ pub fn pn2codon(
             amino_acid.do_checks();
 
             let mut codon = amino_acid.reverse_translate_and_compare(&gene_table);
-            let mut h_clone = header.clone();
-
+            let mut h_clone = format!(">{header}\n");
             codon.push('\n');
-            h_clone.push('\n');
 
-            ret[seq_length - *i] = vec![h_clone, codon]
+            ret[*i] = vec![h_clone, codon]
         });
            
     String::from_iter(ret.iter().cloned().flatten())
